@@ -7,12 +7,11 @@ User friendly magnetic field calculations
 
 Top level module for exposing the public API of usable modules
 """
-from . import plots
-from . import magnets
-from . import utils
-from . import forces
-from .magnets._magnet_base import reset_magnets, list_magnets
-from .utils._routines2D import grid2D, get_field_2D
-from .utils._routines3D import grid3D, slice3D, get_field_3D
+__version__ = "0.4.0"
 
-__all__ = ["magnets", "plots", "utils"]
+from . import forces, magnets, plots, utils
+from .magnets._magnet_base import list, reset
+from .utils._routines2D import get_field_2D, grid2D
+from .utils._routines3D import get_field_3D
+
+__all__ = [forces, magnets, plots, utils, list, reset, get_field_2D, grid2D, get_field_3D]
