@@ -1,19 +1,11 @@
+import numpy as _np
+from numba import njit
+
 from ..magnets import Magnet3D
-from ..utils.global_const import FP_CUTOFF, MU0, ALIGN_CUTOFF
 from ..utils._conversions import get_unit_value_meter
 from ..utils._routines3D import _allocate_field_array3
 from ..utils._vector_structs import Point_Array3
-import numpy as _np
-from numba import njit, guvectorize
-
-__all__ = [
-    "get_centroid",
-    "triangle_area",
-    "get_area_triangles",
-    "get_midpoints",
-    "divide_triangle_centroid",
-    "divide_triangle_regular",
-]
+from ..utils.global_const import ALIGN_CUTOFF, MU0
 
 
 @njit
@@ -39,7 +31,7 @@ def get_centroid(triangle):
 #         result[i] = (triangle[0,i] + triangle[1,i] + triangle[2,i])/3.0
 
 
-@njit
+# @njit
 def triangle_area(triangle):
     """Gets the area of a triangle. Computes the cross product area.
 
@@ -261,4 +253,4 @@ def calc_force_mesh(active_magnet, depth=3, unit="mm"):
     force /= MU0 / scaling_factor / scaling_factor
     torque /= MU0 / scaling_factor / scaling_factor / scaling_factor
 
-    return force, torque
\ No newline at end of file
+    return force, torque
